"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.WinstonLogger = void 0;
var util_1 = __importDefault(require("util"));
var WinstonLogger = /** @class */ (function () {
    function WinstonLogger() {
    }
    Object.defineProperty(WinstonLogger.prototype, "winston", {
        set: function (winston) {
            if (!this._winston)
                this._winston = winston;
        },
        enumerable: false,
        configurable: true
    });
    ;
    WinstonLogger.getInstance = function () {
        if (!WinstonLogger._instance)
            WinstonLogger._instance = new WinstonLogger();
        return WinstonLogger._instance;
    };
    ;
    WinstonLogger.prototype.start = function (environment, combinedLogPath, errorLogPath) {
        try {
            if (!this._winston)
                throw { error: new Error("winston must be set before starting the logger"), errorCode: 400 };
            var customConsolePrintf = this._winston.format.combine(this._winston.format.colorize(), this._winston.format.printf(function (info) {
                var _info = JSON.parse(JSON.stringify(info));
                delete _info.level;
                delete _info.message;
                var infoObjString = Object.keys(_info).length > 0 ? "".concat(JSON.stringify(_info)) : '';
                return "".concat(info.level, " : ").concat(util_1.default.inspect("".concat(new Date().toString(), " : ").concat(info.message, " ").concat(infoObjString), {
                    colors: true
                }));
            }));
            var customFilePrintf = this._winston.format.printf(function (info) {
                var _info = JSON.parse(JSON.stringify(info));
                delete _info.level;
                delete _info.message;
                var infoObjString = Object.keys(_info).length > 0 ? "".concat(JSON.stringify(_info)) : '';
                return "".concat(util_1.default.inspect("".concat(info.level, " : ").concat(new Date().toString(), " : ").concat(info.message, " ").concat(infoObjString), {
                    colors: false
                }));
            }); // {level: 'info' | 'error', 'debug', message: '', error: "error value" }
            var logger = this._winston.createLogger({
                level: 'silly',
                transports: [
                    new this._winston.transports.Console()
                ],
            });
            logger.format = customConsolePrintf;
            if (process.env.NODE_ENV === 'production') {
                console.log('production env :::');
                logger.format = customFilePrintf;
                logger.add(new this._winston.transports.File({
                    filename: errorLogPath,
                    level: 'error'
                }));
                logger.add(new this._winston.transports.File({
                    filename: combinedLogPath,
                    level: 'silly'
                }));
            }
            this._winston.add(logger);
            if (environment === 'production')
                this._winston.winston.info('IN PRODUCTION MODE');
            else
                this._winston.winston.info('IN DEVELOPEMENT MODE');
        }
        catch (error) {
            throw error;
        }
        ;
    };
    ;
    return WinstonLogger;
}());
exports.WinstonLogger = WinstonLogger;
;
